# DeploymentResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**release_id** | **str** |  | 
**environment_id** | **str** |  | 
**tenant_id** | **str** |  | [optional] 
**force_package_download** | **bool** |  | [optional] 
**force_package_redeployment** | **bool** |  | [optional] 
**skip_actions** | **list[str]** |  | [optional] 
**specific_machine_ids** | **list[str]** |  | [optional] 
**excluded_machine_ids** | **list[str]** |  | [optional] 
**deployment_process_id** | **str** |  | [optional] 
**manifest_variable_set_id** | **str** |  | [optional] 
**task_id** | **str** |  | [optional] 
**project_id** | **str** |  | [optional] 
**channel_id** | **str** |  | [optional] 
**use_guided_failure** | **bool** |  | [optional] 
**comments** | **str** |  | [optional] 
**form_values** | **dict(str, str)** |  | [optional] 
**queue_time** | **datetime** |  | [optional] 
**queue_time_expiry** | **datetime** |  | [optional] 
**name** | **str** |  | [optional] 
**created** | **datetime** |  | [optional] 
**changes** | [**list[ReleaseChanges]**](ReleaseChanges.md) |  | [optional] 
**space_id** | **str** |  | [optional] 
**last_modified_on** | **datetime** |  | [optional] 
**last_modified_by** | **str** |  | [optional] 
**links** | **dict(str, str)** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


